@@ -1,23 +1,22 @@
 import logging
 import os
 import sys
-import pkg_resources
-
+from importlib import metadata
 
 log = logging.getLogger(__name__)
 
 
 def load(plugins=(), full_install=True):
     try:
-        version = pkg_resources.get_distribution("virtualfish").version
-        commands = ["set -g VIRTUALFISH_VERSION {}".format(version)]
-    except pkg_resources.DistributionNotFound:
+        version = metadata.version("virtualfish")
+        commands = [f"set -g VIRTUALFISH_VERSION {version}"]
+    except metadata.PackageNotFoundError:
         commands = []
     base_path = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 
     if full_install:
         commands += [
-            "set -g VIRTUALFISH_PYTHON_EXEC {}".format(sys.executable),
+            f"set -g VIRTUALFISH_PYTHON_EXEC {sys.executable}",
             "source {}".format(os.path.join(base_path, "virtual.fish")),
         ]
     else:
@@ -26,9 +25,9 @@ def load(plugins=(), full_install=True):
     for plugin in plugins:
         path = os.path.join(base_path, plugin + ".fish")
         if os.path.exists(path):
-            commands.append("source {}".format(path))
+            commands.append(f"source {path}")
         else:
-            log.error("Plugin does not exist: {}".format(plugin))
+            log.error(f"Plugin does not exist: {plugin}")
             sys.exit(1)
 
     if full_install:
